
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <time.h>
#include "edaq530comm.h"
#include "gnuplot_i.h"

#define PERIOD_US 10000
#define MAX_LENGTH 1000

int main(int argc, char *argv[])
{
	if (argc < 2)
	{
		printf("Run program using argument (for example /dev/ttyUSB0)! The program now exit...\n");
		exit(EXIT_FAILURE);
	}
	unsigned char c='D';
	int fd = open(argv[1], O_RDWR | O_NOCTTY | O_SYNC);

	if(fd == -1)
	{
		printf("Failed to open %s! The program now exit...\n", argv[1]);
		exit(EXIT_FAILURE);
	}
	printf("%s is opened\n", argv[1]);	
	
	print_edaq_id(fd);
	set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);

	int data[3];
	float temp;
	printf("Measuring thermistor temperature on ch A\n");
	
	gnuplot_ctrl *h1;
	double phase ;
	printf("*** example of gnuplot control through C ***\n") ;
	
	h1 = gnuplot_init() ;
	gnuplot_setstyle(h1, "lines") ;
	gnuplot_set_xlabel(h1, "time") ;
    	gnuplot_set_ylabel(h1, "Temperature (°C)") ;
    
    	int count = 0;
    	int i;
    	double x[MAX_LENGTH];
    	double y[MAX_LENGTH];
    	
	while (count < MAX_LENGTH)
	{
		measure_edaq(fd, data);
		temp = get_measured_quantity(data[0], temp_celsius);
		count++;
		y[count-1] = (double) temp;
		x[count-1] = (double) count - 1;
		gnuplot_resetplot(h1) ;
		//gnuplot_cmd(h1, "plot '-' \n");
  		
  		gnuplot_plot_xy(h1, x, y, count, "Temperature");

		//gnuplot_cmd(h1, "e");
		//printf("Temperature:\t%.2f C\n", temp);
		usleep(PERIOD_US);
	}
	gnuplot_close(h1) ;
	close(fd);
	return 0;
}
