
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include "edaq530comm.h"
#include "gnuplot_i.h"

#define DATA_COUNT 300
#define NUM_OF_PLOTS 10


int main(int argc, char *argv[])
{
	if (argc < 2)
	{
		printf("Run program using argument (for example /dev/ttyUSB0)! The program now exit...\n");
		exit(EXIT_FAILURE);
	}
	unsigned char c='D';
	int fd = open_edaq(argv[1]);

	if(fd == -1)
	{
		printf("Failed to open %s! The program now exit...\n", argv[1]);
		exit(EXIT_FAILURE);
	}
	printf("%s is opened\n", argv[1]);
	int data[DATA_COUNT];
	print_edaq_id(fd);
	set_inputs(fd, photo_ch, voltage_ch, voltage_ch);

	set_sampling_freq(fd, 100);
	
	double quantity[DATA_COUNT];
	double x[DATA_COUNT];
	int i, j;
	
	for (i = 0; i < DATA_COUNT; i++)
		x[i] = (float)i / 100;
	
	//
	gnuplot_ctrl *h1;

	h1 = gnuplot_init() ;
	gnuplot_setstyle(h1, "lines") ;
	gnuplot_set_xlabel(h1, "Time (s)") ;
    	gnuplot_set_ylabel(h1, "Voltage (V)") ;
    
    	start_cont_sampling(fd);
    	for (i = 0; i < NUM_OF_PLOTS; i++)
	{
		fill_array_cont_sampling(fd, data, DATA_COUNT);
		gnuplot_resetplot(h1) ;
		for (j = 0; j < DATA_COUNT; j++)
		{
			quantity[j] = - get_measured_quantity(data[j], voltage);
			//printf("quantity %d:\t%.2f C\n", i, quantity[i]);
		}
		
		//gnuplot_cmd(h1, "plot '-' \n");
  		
  		gnuplot_plot_xy(h1, x, quantity, DATA_COUNT, "Plethysmograph");

		//gnuplot_cmd(h1, "e");
		//printf("quantity:\t%.2f C\n", temp);
		//usleep(PERIOD_US);
	}
	
	
	
	//printf("done\n");
	
	
	stop_cont_sampling(fd);
	
	gnuplot_close(h1) ;
	close(fd);
	return 0;
}
