#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <malloc.h>
#include "edaq530comm.h"

#define PERIOD_MS 500

typedef struct meas_data{
	int fd;
	quantity_type type;
	GtkLabel *label;
} meas_data;

static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
{
	return FALSE;
}

static void destroy(GtkWidget *widget, gpointer data)
{
	close(*(int* ) data);	
	gtk_main_quit();
}

gint measure_value(gpointer data)
{
	int meas[3];
	measure_edaq(((meas_data* )data)->fd, meas);

	float value = get_measured_quantity(meas[0], ((meas_data* )data)->type);

	gchar* buf;
	switch (((meas_data* )data)->type)
	{
		case voltage:
			buf = g_strdup_printf("<span font_desc=\"32.0\">%.4f V</span>", value);
			break;
		case resistance:
			buf = g_strdup_printf("<span font_desc=\"32.0\">%.1f Ohm</span>", value);
			break;
		case temp_kelvin:
			buf = g_strdup_printf("<span font_desc=\"32.0\">%.2f K</span>", value);
			break;

		case temp_celsius:
			buf = g_strdup_printf("<span font_desc=\"32.0\">%.2f °C</span>", value);
			break;
	}
	
	gtk_label_set_markup(((meas_data* )data)->label, buf);
	g_free(buf);
	return TRUE;
}

int main( int argc, char *argv[] )
{
	if (argc < 3)
	{
		printf("Run program using arguments (for example /dev/ttyUSB0 voltage)! The program now exit...\n");
		exit(EXIT_FAILURE);
	}
	unsigned char c='D';
	int fd = open_edaq(argv[1]);

	if(fd == -1)
	{
		printf("Failed to open %s! The program now exit...\n", argv[1]);
		exit(EXIT_FAILURE);
	}
	printf("%s is opened\n", argv[1]);	
	print_edaq_id(fd);
	
	meas_data *m_data;
	m_data = malloc (sizeof(meas_data)); 
	
	if (!(strcmp(argv[2], "temp_celsius")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		m_data->type = temp_celsius;
	}
	else if (!(strcmp(argv[2], "temp_kelvin")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		m_data->type = temp_kelvin;
	}
	else if (!(strcmp(argv[2], "resistance")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		m_data->type = resistance;
	}
	else if (!(strcmp(argv[2], "voltage")))
	{
		set_inputs(fd, voltage_ch, voltage_ch, voltage_ch);
		m_data->type = voltage;
	}
	else if (!(strcmp(argv[2], "inamp")))
	{
		set_inputs(fd, inamp_ch, voltage_ch, voltage_ch);
		m_data->type = voltage;
	}
	else if (!(strcmp(argv[2], "voltage_diff")))
	{
		set_inputs(fd, voltage_ch, voltage_ch, voltage_ch);
		m_data->type = voltage;
	}
	else if (!(strcmp(argv[2], "photo")))
	{
		set_inputs(fd, photo_ch, voltage_ch, voltage_ch);
		m_data->type = voltage;
	}
	else
	{
		g_printf("Invalid argument %s. Valid arguments are: voltage, voltage_diff, resistance, temp_kelvin, temp_celsius, inamp, photo. The program now exit...\n", argv[2]);
		exit(EXIT_FAILURE);
	}

	//GTK
	GtkWidget *window;
	GtkWidget *label;
    
	gtk_init(&argc, &argv);
    	
	//window
	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(window), argv[2]);
	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file("./icon/plet_icon2.png", NULL);
	gtk_window_set_icon(GTK_WINDOW(window), pixbuf);
	g_signal_connect(window, "delete_event", G_CALLBACK(delete_event), NULL);
	g_signal_connect(window, "destroy", G_CALLBACK(destroy), &fd);	
	//g_signal_connect(window, "destroy", G_CALLBACK(destroy), NULL);
	gtk_container_set_border_width(GTK_CONTAINER(window), 10);

	//label
	label = gtk_label_new("");
	
	m_data->fd = fd;
	m_data->label = (GtkLabel *) label;
	
	gtk_widget_set_size_request(label, 250, 150);
	gtk_container_add(GTK_CONTAINER(window), label);
	
	g_timeout_add(PERIOD_MS, measure_value, m_data);
	gtk_widget_show(label);
	gtk_widget_show(window);
	
    
	gtk_main();
    
	return 0;
}
