
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <unistd.h>
#include "edaq530comm.h"




int main(int argc, char *argv[])
{
	if (argc < 3)
	{
		printf("Run program using arguments (for example /dev/ttyUSB0 voltage)! The program now exit...\n");
		exit(EXIT_FAILURE);
	}
	int fd = open(argv[1], O_RDWR | O_NOCTTY | O_SYNC);
	int data[3];
	float result = 0.0f;

	if(fd == -1)
	{
		printf("Failed to open %s! The program now exit...\n", argv[1]);
		exit(EXIT_FAILURE);
	}
	printf("%s is opened\n", argv[1]);	
	print_edaq_id(fd);
	
	if (!(strcmp(argv[2], "temp_celsius")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		measure_edaq(fd, data);
		result = get_measured_quantity(data[0], temp_celsius);
		printf("Measuring thermistor temperature on chA\n");
		printf("Temperature:\t%.2f C\n", result);
	}
	else if (!(strcmp(argv[2], "temp_kelvin")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		measure_edaq(fd, data);
		result = get_measured_quantity(data[0], temp_kelvin);
		printf("Measuring thermistor temperature on chA\n");
		printf("Temperature:\t%.2f K\n", result);
	}
	else if (!(strcmp(argv[2], "resistance")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		measure_edaq(fd, data);
		result = get_measured_quantity(data[0], resistance);
		printf("Measuring resistance on chA\n");
		printf("Resitance:\t%.1f Ohm\n", result);
	}
	else if (!(strcmp(argv[2], "voltage")))
	{
		set_inputs(fd, voltage_ch, voltage_ch, voltage_ch);
		measure_edaq(fd, data);
		result = get_measured_quantity(data[0], voltage);
		printf("Measuring voltage on chA\n");
		printf("Voltage:\t%.5f V\n", result);
	}
	else if (!(strcmp(argv[2], "inamp")))
	{
		set_inputs(fd, inamp_ch, voltage_ch, voltage_ch);
		measure_edaq(fd, data);
		result = get_measured_quantity(data[0], voltage);
		printf("Measuring inamp on chA\n");
		printf("Voltage:\t%.5f V\n", result);
	}
	else if (!(strcmp(argv[2], "voltage_diff")))
	{
		set_inputs(fd, voltage_ch, voltage_ch, voltage_ch);
		measure_edaq(fd, data);
		result = get_measured_quantity(data[0], voltage) - get_measured_quantity(data[1], voltage);
		printf("Measuring voltage chA-chB\n");
		printf("Voltage:\t%.5f V\n", result);
	}
	else if (!(strcmp(argv[2], "photo")))
	{
		set_inputs(fd, photo_ch, voltage_ch, voltage_ch);
		measure_edaq(fd, data);
		result = get_measured_quantity(data[0], voltage);
		printf("Measuring photo on chA\n");
		printf("Voltage:\t%.5f V\n", result);
	}
	else
	{
		printf("Invalid argument %s. Valid arguments are: voltage, voltage_diff, resistance, temp_kelvin, temp_celsius, inamp, photo. The program now exit...\n", argv[2]);
		exit(EXIT_FAILURE);
	}
	close(fd);
	fflush(stdout);
	return 0;
}
